@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::RecordReader;
 #ABSTRACT: Koha biblio/authority records reader
-$Koha::Contrib::Tamil::RecordReader::VERSION = '0.047';
+$Koha::Contrib::Tamil::RecordReader::VERSION = '0.048';
 use Moose;
 
 with 'MooseX::RW::Reader';
@@ -188,7 +188,7 @@ sub get_biblio_xml {
     }
     if ( C4::Context->preference('Frantiq') ) {
         require Frantiq::Pactol::BiblioNormalizer;
-        $marcxml = Frantiq::Pactol::BiblioNormalizer::process($marcxml);
+        Frantiq::Pactol::BiblioNormalizer::process(\$marcxml);
     }
     return $marcxml;
 }
@@ -283,7 +283,7 @@ Koha::Contrib::Tamil::RecordReader - Koha biblio/authority records reader
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 SYNOPSYS
 
